@@ -15,10 +15,10 @@ class Cache:
 		self._spark = spark
 		self._items = set()
 		self._echo = echo
+		self._n_jobs = n_jobs
 
-	@staticmethod
-	def get_key(item):
-		return smart_hash(item, n_jobs=n_jobs, base=32)
+	def get_key(self, item):
+		return smart_hash(item, n_jobs=self._n_jobs, base=32)
 
 	def get_path(self, key):
 		"""
