@@ -139,13 +139,13 @@ def make_hashable(obj, n_jobs):
 		return make_hashable(obj.__hashkey__())
 	else:
 		if isinstance(obj, (tuple, list)):
-			return tuple((make_hashable(e) for e in obj))
+			return tuple((make_hashable(e, n_jobs=n_jobs) for e in obj))
 
 		if isinstance(obj, dict):
-			return tuple(sorted((k, make_hashable(v)) for k, v in obj.items()))
+			return tuple(sorted((k, make_hashable(v, n_jobs=n_jobs)) for k, v in obj.items()))
 
 		if isinstance(obj, (set, frozenset)):
-			return tuple(sorted(make_hashable(e) for e in obj))
+			return tuple(sorted(make_hashable(e, n_jobs=n_jobs) for e in obj))
 
 		if isinstance(obj, (SparkDF, PandasDF)):
 			return make_dataframe_hashable(data=obj, n_jobs=n_jobs)
